@@ -148,11 +148,11 @@ take_block([N-['|'|RL1]|LT], _, Table, Rest) :-
     rest_table(LT, N, RL, Rest),
     !,
     Table = table(class=wiki, [tr(R0)|RL]).
-take_block([0-[-,-|More]|LT], _, Block, LT) :-  % seperation line
+take_block([0-[-,-|More]|LT], _, Block, LT) :-  % separation line
     maplist(=(-), More),
     !,
     Block = hr([]).
-take_block([_-Line|LT], _, Block, LT) :-        % seperation line
+take_block([_-Line|LT], _, Block, LT) :-        % separation line
     ruler(Line),
     !,
     Block = hr([]).
@@ -171,12 +171,26 @@ take_block([I-L1|LT], BaseIndent, Elem, Rest) :-
     rest_par(LT, PT, I, BaseIndent, MaxI, Rest),
     (   MaxI >= BaseIndent+16
     ->  Elem = center(Par)
-    ;   MaxI >= BaseIndent+4
-    ->  Elem = blockquote(Par)
+    ;   phrase(blockquote(BQ), Par)
+    ->  Elem = blockquote(BQ)
     ;   Elem = p(Par)
     ).
 take_block([Verb|Lines], _, Verb, Lines).
 
+blockquote(Clean) -->
+    [>, ' '],
+    bq_lines(Clean).
+
+bq_lines([' '|Par]) -->
+    ['\n'], !, [>,' '],
+    bq_lines(Par).
+bq_lines([H|T]) -->
+    [H],
+    bq_lines(T).
+bq_lines([]) -->
+    [].
+
+
 %!  ruler(+Line) is semidet.
 %
 %   True if Line contains 3 ruler chars and otherwise spaces.
@@ -519,6 +533,7 @@ label_cont(Name) --> [w(Name)].
 md_section_line(Line1, Line2, Header) :-
     Line1 \== [],
     section_underline(Line2, Type),
+    is_list(Line1),
     phrase(wiki_words(_), Line1),  % Should not have structure elements
     !,
     (   phrase(labeled_section_line(Title, Attrs), Line1)
