@@ -237,7 +237,7 @@ pl_format_predicate(term_t chr, term_t descr)
   if ( !format_predicates )
     format_predicates = newHTable(8);
 
-  addNewHTable(format_predicates, (void *)(intptr_t)c, proc);
+  updateHTable(format_predicates, (void *)(intptr_t)c, proc);
 
   succeed;
 }
@@ -296,7 +296,7 @@ format_impl(IOSTREAM *out, term_t format, term_t Args, Module m)
   int rval;
   PL_chars_t fmt;
 
-  if ( !PL_get_text(format, &fmt, CVT_ALL|BUF_RING) )
+  if ( !PL_get_text(format, &fmt, CVT_ALL|BUF_STACK) )
     return PL_error("format", 3, NULL, ERR_TYPE, ATOM_text, format);
 
   if ( (argc = (int)lengthList(args, FALSE)) >= 0 )
